@@ -33,10 +33,9 @@
 	#define __JUCE_UNITTEST_JUCEHEADER__
 #endif
 
-#include <tr1/memory>
+#include <memory>
 #include <string>
 #include <QtGui/QImage>
-#include "JuceLibraryCode/JuceHeader.h"
 #include "AudioResampler.h"
 #include "ClipBase.h"
 #include "Color.h"
@@ -44,18 +43,10 @@
 #include "EffectBase.h"
 #include "Effects.h"
 #include "EffectInfo.h"
-#include "FFmpegReader.h"
 #include "Fraction.h"
-#include "FrameMapper.h"
-#ifdef USE_IMAGEMAGICK
-	#include "ImageReader.h"
-	#include "TextReader.h"
-#endif
-#include "QtImageReader.h"
-#include "ChunkReader.h"
 #include "KeyFrame.h"
 #include "ReaderBase.h"
-#include "DummyReader.h"
+#include "JuceHeader.h"
 
 using namespace std;
 using namespace openshot;
@@ -124,23 +115,26 @@ namespace openshot {
 		bool manage_reader;
 
 		/// Adjust frame number minimum value
-		long int adjust_frame_number_minimum(long int frame_number);
+		int64_t adjust_frame_number_minimum(int64_t frame_number);
 
 		/// Apply effects to the source frame (if any)
-		tr1::shared_ptr<Frame> apply_effects(tr1::shared_ptr<Frame> frame);
+		std::shared_ptr<Frame> apply_effects(std::shared_ptr<Frame> frame);
 
 		/// Get file extension
 		string get_file_extension(string path);
 
 		/// Get a frame object or create a blank one
-		tr1::shared_ptr<Frame> GetOrCreateFrame(long int number);
+		std::shared_ptr<Frame> GetOrCreateFrame(int64_t number);
 
 		/// Adjust the audio and image of a time mapped frame
-		tr1::shared_ptr<Frame> get_time_mapped_frame(tr1::shared_ptr<Frame> frame, long int frame_number) throw(ReaderClosed);
+		void get_time_mapped_frame(std::shared_ptr<Frame> frame, int64_t frame_number);
 
 		/// Init default settings for a clip
 		void init_settings();
 
+		/// Update default rotation from reader
+		void init_reader_rotation();
+
 		/// Sort effects by order
 		void sort_effects();
 
@@ -152,6 +146,7 @@ namespace openshot {
 		ScaleType scale; ///< The scale determines how a clip should be resized to fit it's parent
 		AnchorType anchor; ///< The anchor determines what parent a clip should snap to
         FrameDisplayType display; ///< The format to display the frame number (if any)
+		VolumeMixType mixing; ///< What strategy should be followed when mixing audio with other clips
 
 		/// Default Constructor
 		Clip();
@@ -172,7 +167,7 @@ namespace openshot {
 		void AddEffect(EffectBase* effect);
 
 		/// Close the internal reader
-		void Close() throw(ReaderClosed);
+		void Close();
 
 		/// Return the list of effects on the timeline
 		list<EffectBase*> Effects() { return effects; };
@@ -181,31 +176,31 @@ namespace openshot {
 		///
 		/// @returns The requested frame (containing the image)
 		/// @param requested_frame The frame number that is requested
-		tr1::shared_ptr<Frame> GetFrame(long int requested_frame) throw(ReaderClosed);
+		std::shared_ptr<Frame> GetFrame(int64_t requested_frame);
 
 		/// Open the internal reader
-		void Open() throw(InvalidFile, ReaderClosed);
+		void Open();
 
 		/// @brief Set the current reader
 		/// @param new_reader The reader to be used by this clip
 		void Reader(ReaderBase* new_reader);
 
 		/// Get the current reader
-		ReaderBase* Reader() throw(ReaderClosed);
+		ReaderBase* Reader();
 
 		/// Override End() method
-		float End() throw(ReaderClosed); ///< Get end position (in seconds) of clip (trim end of video), which can be affected by the time curve.
+		float End(); ///< Get end position (in seconds) of clip (trim end of video), which can be affected by the time curve.
 		void End(float value) { end = value; } ///< Set end position (in seconds) of clip (trim end of video)
 
 		/// Get and Set JSON methods
 		string Json(); ///< Generate JSON string of this object
-		void SetJson(string value) throw(InvalidJSON); ///< Load JSON string into this object
+		void SetJson(string value); ///< Load JSON string into this object
 		Json::Value JsonValue(); ///< Generate Json::JsonValue for this object
 		void SetJsonValue(Json::Value root); ///< Load Json::JsonValue into this object
 
 		/// Get all properties for a specific frame (perfect for a UI to display the current state
 		/// of all properties at any time)
-		string PropertiesJSON(long int requested_frame);
+		string PropertiesJSON(int64_t requested_frame);
 
 		/// @brief Remove an effect from the clip
 		/// @param effect Remove an effect from the clip.
